diff --git a/js/stlib_picker.js b/js/stlib_picker.js
index b7f1183..097199e 100644
--- a/js/stlib_picker.js
+++ b/js/stlib_picker.js
@@ -2,11 +2,12 @@
  * @file
  * This library requires JQuery.
  */
+
 // It also requires stcommon.js in your header for an official list of services
 // stlib_picker.defaultServices defines the services from stcommon that get loaded as the default services in the picker
 // Styling can be found in stlib_picker.css and should be linked in the page.
 // To get selected services as an array of strings:  (ie ["twitter", "sharethis", "facebook"] )
-//   Call: var answer = stlib_picker.pickerList[uniqueID]["getServices"]();.
+// Call: var answer = stlib_picker.pickerList[uniqueID]["getServices"]();.
 var stlib_picker = {}, isSecure = ("https:" == document.location.protocol) ? true : false;
 stlib_picker.pickerList = [];
 stlib_picker.defaultServices = ["sharethis", "tumblr", "bebo"];
diff --git a/sharethis.module b/sharethis.module
index 4ff7f72..718e126 100644
--- a/sharethis.module
+++ b/sharethis.module
@@ -3,13 +3,12 @@
  * @file
  * A module that adds one of the ShareThis widget to your website.
  */
+
 use Drupal\Core\Url;
 use Drupal\Core\Routing\RouteMatchInterface;
 use Drupal\Core\Entity\EntityInterface;
 use Drupal\Core\Entity\Display\EntityViewDisplayInterface;
 
-
-
 /**
  * Implements hook_help().
  */
@@ -44,7 +43,6 @@ function sharethis_theme($existing, $type, $theme, $path) {
       'function' => 'theme_sharethis_block',
     ),
   );
-  return $theme;
 }
 
 /**
@@ -80,17 +78,10 @@ function sharethis_entity_extra_field_info() {
 }
 
 /**
- * Implements hook_ENTITY_TYPE_view() for node entities.
+ * Implements hook_ENTITY_TYPE_view().
  *
  * Inserts ShareThis widget code onto each node view.
  * TODO: Want to add the option somewhere to select nodes.
- *
- * @param node
- *   The node that is being acted upon
- * @param view_mode
- *   The type of view (teaser, full, etc)
- * @param langcode
- *   Information about the language
  */
 function sharethis_node_view(array &$build, EntityInterface $node, EntityViewDisplayInterface $display, $view_mode) {
   $sharethis_manager = \Drupal::service('sharethis.manager');
@@ -121,7 +112,7 @@ function sharethis_node_view(array &$build, EntityInterface $node, EntityViewDis
     case 'content':
       $enabled_types = $data_options['node_types'];
       if (isset($enabled_types[$node->bundle()]) && $enabled_types[$node->bundle()] === $node->bundle()) {
-        $st_js = $sharethis_manager->sharethis_include_js();
+        $st_js = $sharethis_manager->sharethisIncludeJs();
         $content = $sharethis_manager->renderSpans($data_options, $title, $path);
         $build['sharethis_content'] = array(
           '#theme' => 'sharethis_block',
@@ -144,7 +135,7 @@ function sharethis_node_view(array &$build, EntityInterface $node, EntityViewDis
     case 'links':
       $enabled_view_modes = $sharethis_settings->get('sharethisnodes.' . $node->bundle());
       if (isset($enabled_view_modes[$view_mode]) && $enabled_view_modes[$view_mode]) {
-        $st_js = $sharethis_manager->sharethis_include_js();
+        $st_js = $sharethis_manager->sharethisIncludeJs();
         $content = $sharethis_manager->renderSpans($data_options, $title, $path);
         $links['sharethis'] = array(
           'title' => array(
@@ -186,7 +177,7 @@ function sharethis_comment_view(array &$build, EntityInterface $comment, EntityV
   $sharethis_manager = \Drupal::service('sharethis.manager');
   $sharethis_settings = \Drupal::config('sharethis.settings');
   if ($sharethis_settings->get('comments') == 1) {
-    $st_js = $sharethis_manager->sharethis_include_js();
+    $st_js = $sharethis_manager->sharethisIncludeJs();
     $data_options = $sharethis_manager->getOptions();
     $current_path = \Drupal::routeMatch()->getRouteName() ? Url::fromRouteMatch(\Drupal::routeMatch())->getInternalPath() : '';
     $path = isset($current_path) ? $current_path : '<front>';
diff --git a/src/Form/SharethisConfigurationForm.php b/src/Form/SharethisConfigurationForm.php
index 955e15d..959961f 100644
--- a/src/Form/SharethisConfigurationForm.php
+++ b/src/Form/SharethisConfigurationForm.php
@@ -18,7 +18,7 @@ use Symfony\Component\DependencyInjection\ContainerInterface;
 use Drupal\Core\Entity\EntityManagerInterface;
 
 /**
- * Provides a settings for sharethis modle.
+ * Provides a settings for sharethis module.
  */
 class SharethisConfigurationForm extends ConfigFormBase {
 
@@ -50,15 +50,15 @@ class SharethisConfigurationForm extends ConfigFormBase {
    *   The factory for configuration objects.
    * @param \Drupal\Core\Extension\ModuleHandlerInterface $module_handler
    *   The module handler.
-   * @param \Drupal\sharethis\SharethisManagerInterface $sharethisManager
+   * @param \Drupal\sharethis\SharethisManagerInterface $sharethis_manager
    *   The sharethis Manager.
    */
-  public function __construct(ConfigFactoryInterface $config_factory, ModuleHandlerInterface $module_handler, EntityManagerInterface $entity_manager, SharethisManagerInterface $sharethisManager) {
+  public function __construct(ConfigFactoryInterface $config_factory, ModuleHandlerInterface $module_handler, EntityManagerInterface $entity_manager, SharethisManagerInterface $sharethis_manager) {
     parent::__construct($config_factory);
 
     $this->moduleHandler = $module_handler;
     $this->entityManager = $entity_manager;
-    $this->sharethisManager = $sharethisManager;
+    $this->sharethisManager = $sharethis_manager;
   }
 
   /**
@@ -101,12 +101,7 @@ class SharethisConfigurationForm extends ConfigFormBase {
     $config = $this->config('sharethis.settings');
 
     $current_options_array = $this->sharethisManager->getOptions();
-    // Create the variables related to widget choice.
-    $widget_type = $current_options_array['widget'];
-    $widget_markup = "";
-    if ($widget_type == "st_multi") {
-      $widget_markup = "st_multi";
-    }
+
     // Create the variables related to button choice.
     $button_choice = $current_options_array['buttons'];
     // Create the variables related to services chosen.
@@ -139,7 +134,7 @@ class SharethisConfigurationForm extends ConfigFormBase {
       ),
       '#default_value' => $button_choice,
       '#title' => t("Choose a button style:"),
-      '#prefix' => '<div class="st_widgetContain"><div class="st_spriteCover"><img id="stb_sprite" class="st_buttonSelectSprite ' . $button_choice . '" src="' . $base_url . '/' . $my_path . '/img/preview_sprite.png"></img></div><div class="st_widgetPic"><img class="st_buttonSelectImage" src="' . $base_url . '/' . $my_path . '/img/preview_bg.png" /></div>',
+      '#prefix' => '<div class="st_widgetContain"><div class="st_spriteCover"><img id="stb_sprite" class="st_buttonSelectSprite ' . $button_choice . '" src="' . $base_url . '/' . $my_path . '/img/preview_sprite.png" /></div><div class="st_widgetPic"><img class="st_buttonSelectImage" src="' . $base_url . '/' . $my_path . '/img/preview_bg.png" /></div>',
       '#suffix' => '</div>',
     );
     $form['options']['service_option'] = array(
@@ -215,7 +210,6 @@ class SharethisConfigurationForm extends ConfigFormBase {
       $modes[$mode] = $mode_info['label'];
     }
     // Get a list of content types and view modes.
-    $view_modes_selected = $current_options_array['view_modes'];
     foreach ($entity_bundles as $bundle => $bundle_info) {
       $form['context']['links'][$bundle . '_options'] = array(
         '#title' => t('%label View Modes', array('%label' => $bundle_info['label'])),
@@ -347,7 +341,8 @@ class SharethisConfigurationForm extends ConfigFormBase {
     // Additional filters for the option extras input.
     $input_values['option_extras'] = (isset($input_values['option_extras'])) ? $input_values['option_extras'] : array();
 
-    // Sanitize the publisher ID option.  Since it's a text field, remove anything that resembles code.
+    // Sanitize the publisher ID option. Since it's a text field,
+    // remove anything that resembles code.
     $input_values['publisherID'] = Xss::filter($input_values['publisherID']);
 
     if ($input_values['callesi'] == 1) {
@@ -376,7 +371,7 @@ class SharethisConfigurationForm extends ConfigFormBase {
     $values = $form_state->getValues();
     $input_values = $form_state->getUserInput();
     $config = $this->config('sharethis.settings');
-    // If the location is changing to/from 'content', clear the Field Info cache.
+    // If the location change to/from 'content', clear the Field Info cache.
     $current_location = $config->get('location');
     $new_location = $values['location'];
     if (($current_location == 'content' || $new_location == 'content') && $current_location != $new_location) {
diff --git a/src/Plugin/Block/SharethisBlock.php b/src/Plugin/Block/SharethisBlock.php
index c36867f..bcd7beb 100644
--- a/src/Plugin/Block/SharethisBlock.php
+++ b/src/Plugin/Block/SharethisBlock.php
@@ -46,15 +46,15 @@ class SharethisBlock extends BlockBase implements ContainerFactoryPluginInterfac
    *   The plugin_id for the plugin instance.
    * @param mixed $plugin_definition
    *   The plugin implementation definition.
-   * @param \Drupal\Core\Extension\ModuleHandlerInterface $module_handler
-   *   The module manager service.
    * @param \Drupal\Core\Config\Config $sharethis_settings
    *   The config object for 'sharethis.settings'.
+   * @param \Drupal\sharethis\SharethisManagerInterface $sharethis_manager
+   *   The module manager service.
    */
-  public function __construct(array $configuration, $plugin_id, $plugin_definition, Config $sharethis_settings, SharethisManagerInterface $sharethisManager) {
+  public function __construct(array $configuration, $plugin_id, $plugin_definition, Config $sharethis_settings, SharethisManagerInterface $sharethis_manager) {
     parent::__construct($configuration, $plugin_id, $plugin_definition);
     $this->sharethisSettings = $sharethis_settings;
-    $this->sharethisManager = $sharethisManager;
+    $this->sharethisManager = $sharethis_manager;
   }
 
   /**
@@ -75,7 +75,7 @@ class SharethisBlock extends BlockBase implements ContainerFactoryPluginInterfac
    */
   public function build() {
     if ($this->sharethisSettings->get('location') === 'block') {
-      $st_js = $this->sharethisManager->sharethis_include_js();
+      $st_js = $this->sharethisManager->sharethisIncludeJs();
       $markup = $this->sharethisManager->blockContents();
       return [
         '#theme' => 'sharethis_block',
diff --git a/src/Plugin/Block/SharethisWidgetBlock.php b/src/Plugin/Block/SharethisWidgetBlock.php
index b216e94..de10279 100644
--- a/src/Plugin/Block/SharethisWidgetBlock.php
+++ b/src/Plugin/Block/SharethisWidgetBlock.php
@@ -49,15 +49,15 @@ class SharethisWidgetBlock extends BlockBase implements ContainerFactoryPluginIn
    *   The plugin_id for the plugin instance.
    * @param mixed $plugin_definition
    *   The plugin implementation definition.
-   * @param \Drupal\Core\Extension\ModuleHandlerInterface $module_handler
-   *   The module manager service.
    * @param \Drupal\Core\Config\Config $sharethis_settings
    *   The config object for 'sharethis.settings'.
+   * @param \Drupal\sharethis\SharethisManagerInterface $sharethis_manager
+   *   The module manager service.
    */
-  public function __construct(array $configuration, $plugin_id, $plugin_definition, Config $sharethis_settings, SharethisManagerInterface $sharethisManager) {
+  public function __construct(array $configuration, $plugin_id, $plugin_definition, Config $sharethis_settings, SharethisManagerInterface $sharethis_manager) {
     parent::__construct($configuration, $plugin_id, $plugin_definition);
     $this->sharethisSettings = $sharethis_settings;
-    $this->sharethisManager = $sharethisManager;
+    $this->sharethisManager = $sharethis_manager;
   }
 
   /**
@@ -86,8 +86,7 @@ class SharethisWidgetBlock extends BlockBase implements ContainerFactoryPluginIn
   /**
    * {@inheritdoc}
    */
-  function blockForm($form, FormStateInterface $form_state) {
-    $formValues = $form_state->getUserInput();
+  public function blockForm($form, FormStateInterface $form_state) {
     $description = $this->t('Variable - Different per URL');
     $description .= '<br />';
     $description .= $this->t('External - Useful in iframes (Facebook Tabs, etc.)');
@@ -131,7 +130,7 @@ class SharethisWidgetBlock extends BlockBase implements ContainerFactoryPluginIn
    */
   public function build() {
     if ($this->sharethisSettings->get('location') === 'block') {
-      $st_js = $this->sharethisManager->sharethis_include_js();
+      $st_js = $this->sharethisManager->sharethisIncludeJs();
       if ($this->configuration['sharethis_path'] == 'external') {
         $mpath = $this->configuration['sharethis_path_external'];
       }
diff --git a/src/Plugin/Views/field/SharethisNode.php b/src/Plugin/Views/field/SharethisNode.php
index f8faeec..f89feb3 100644
--- a/src/Plugin/Views/field/SharethisNode.php
+++ b/src/Plugin/Views/field/SharethisNode.php
@@ -33,7 +33,7 @@ class SharethisNode extends FieldPluginBase {
   public function render(ResultRow $values) {
     $sharethis_manager = \Drupal::service('sharethis.manager');
     $node = $values->_entity;
-    $mTitle = $node->getTitle();
+    $m_title = $node->getTitle();
     $path = $node->urlInfo();
     $path = $path->getInternalPath();
     global $base_url;
@@ -42,10 +42,10 @@ class SharethisNode extends FieldPluginBase {
         'absolute' => TRUE,
       )
     );
-    $mPath = $path_obj->toString();
+    $m_path = $path_obj->toString();
     $data_options = $sharethis_manager->getOptions();
-    $st_js = $sharethis_manager->sharethis_include_js();
-    $content = $sharethis_manager->renderSpans($data_options, $mTitle, $mPath);
+    $st_js = $sharethis_manager->sharethisIncludeJs();
+    $content = $sharethis_manager->renderSpans($data_options, $m_title, $m_path);
     return [
       '#theme' => 'sharethis_block',
       '#content' => $content,
diff --git a/src/SharethisManager.php b/src/SharethisManager.php
index 1d7957c..f173901 100644
--- a/src/SharethisManager.php
+++ b/src/SharethisManager.php
@@ -50,31 +50,30 @@ class SharethisManager implements SharethisManagerInterface {
    * {@inheritdoc}
    */
   public function getOptions() {
-    $sharethisConfig = $this->configFactory->get('sharethis.settings');
+    $sharethis_config = $this->configFactory->get('sharethis.settings');
 
-    $default_sharethis_nodetypes = array('article' => 'article', 'page' => 'page');
     $view_modes = array();
     foreach (array_keys(NodeType::loadMultiple()) as $type) {
       $view_modes[$type] = array('article' => 'article', 'page' => 'page');
     }
 
     return [
-      'buttons' => $sharethisConfig->get('button_option', 'stbc_button'),
-      'publisherID' => $sharethisConfig->get('publisherID'),
-      'services' => $sharethisConfig->get('service_option'),
-      'option_extras' => $sharethisConfig->get('option_extras'),
-      'widget' => $sharethisConfig->get('widget_option'),
-      'onhover' => $sharethisConfig->get('option_onhover'),
-      'neworzero' => $sharethisConfig->get('option_neworzero'),
-      'twitter_suffix' => $sharethisConfig->get('twitter_suffix'),
-      'twitter_handle' => $sharethisConfig->get('twitter_handle'),
-      'twitter_recommends' => $sharethisConfig->get('twitter_recommends'),
-      'late_load' => $sharethisConfig->get('late_load'),
+      'buttons' => $sharethis_config->get('button_option', 'stbc_button'),
+      'publisherID' => $sharethis_config->get('publisherID'),
+      'services' => $sharethis_config->get('service_option'),
+      'option_extras' => $sharethis_config->get('option_extras'),
+      'widget' => $sharethis_config->get('widget_option'),
+      'onhover' => $sharethis_config->get('option_onhover'),
+      'neworzero' => $sharethis_config->get('option_neworzero'),
+      'twitter_suffix' => $sharethis_config->get('twitter_suffix'),
+      'twitter_handle' => $sharethis_config->get('twitter_handle'),
+      'twitter_recommends' => $sharethis_config->get('twitter_recommends'),
+      'late_load' => $sharethis_config->get('late_load'),
       'view_modes' => $view_modes,
-      'cns' => $sharethisConfig->get('cns'),
-      'callesi' => (NULL == $sharethisConfig->get('cns')) ? 1 : 0,
-      'node_types' => $sharethisConfig->get('node_types'),
-      'shorten' => $sharethisConfig->get('option_shorten'),
+      'cns' => $sharethis_config->get('cns'),
+      'callesi' => (NULL == $sharethis_config->get('cns')) ? 1 : 0,
+      'node_types' => $sharethis_config->get('node_types'),
+      'shorten' => $sharethis_config->get('option_shorten'),
     ];
   }
 
@@ -82,12 +81,12 @@ class SharethisManager implements SharethisManagerInterface {
   /**
    * {@inheritdoc}
    */
-  function blockContents() {
+  public function blockContents() {
 
-    $sharethisConfig = $this->configFactory->get('sharethis.settings');
+    $sharethis_config = $this->configFactory->get('sharethis.settings');
     $config = $this->configFactory->get('system.site');
-    if ($sharethisConfig->get('location') == 'block') {
-      // First get all of the options for the sharethis widget from the database:
+    if ($sharethis_config->get('location') == 'block') {
+      // First Get all of the options for sharethis widget from database.
       $data_options = $this->getOptions();
       $current_path = \Drupal::routeMatch()->getRouteName() ? Url::fromRouteMatch(\Drupal::routeMatch())->getInternalPath() : '';
       $path = isset($current_path) ? $current_path : '<front>';
@@ -97,19 +96,19 @@ class SharethisManager implements SharethisManagerInterface {
           'absolute' => TRUE,
         )
       );
-      $mPath = $path_obj->toString();
+      $m_path = $path_obj->toString();
       $request = \Drupal::request();
       $route_match = \Drupal::routeMatch();
-      $mTitle = $this->titleResolver->getTitle($request, $route_match->getRouteObject());
-      $mtitle = is_object($mTitle) ? $mTitle->getUntranslatedString() : $config->get('name');
-      return $this->renderSpans($data_options, $mtitle, $mPath);
+      $mtitle = $this->titleResolver->getTitle($request, $route_match->getRouteObject());
+      $m_title = is_object($mtitle) ? $mtitle->getUntranslatedString() : $config->get('name');
+      return $this->renderSpans($data_options, $m_title, $m_path);
 
     }
   }
   /**
    * {@inheritdoc}
    */
-  function widgetContents($settings) {
+  public function widgetContents($settings) {
     $mpath = $settings['m_path'];
     $mtitle = $settings['m_title'];
     $data_options = $this->getOptions();
@@ -119,7 +118,7 @@ class SharethisManager implements SharethisManagerInterface {
   /**
    * {@inheritdoc}
    */
-  function sharethis_include_js() {
+  public function sharethisIncludeJs() {
     $has_run = &drupal_static(__FUNCTION__, FALSE);
     if (!$has_run) {
       // These are the ShareThis scripts:
@@ -134,49 +133,48 @@ class SharethisManager implements SharethisManagerInterface {
         $st_js .= 'var ' . $name . ' = ' . Json::decode($value) . ';';
 
       }
-      $stlight = $this->get_stLight_options($data_options);
-      $st_js = $stlight;
-      return $st_js;
+      $st_js = $this->getShareThisLightOptions($data_options);
       $has_run = TRUE;
+      return $st_js;
     }
   }
 
   /**
    * {@inheritdoc}
    */
-  function get_stLight_options($data_options) {
+  public function getShareThisLightOptions($data_options) {
     // Provide the publisher ID.
-    $paramsStLight = array(
+    $params_stlight = array(
       'publisher' => $data_options['publisherID'],
     );
-    $paramsStLight['version'] = ($data_options['widget'] == 'st_multi') ? "5x" : "4x";
+    $params_stlight['version'] = ($data_options['widget'] == 'st_multi') ? "5x" : "4x";
     if ($data_options['callesi'] == 0) {
-      $paramsStLight["doNotCopy"] = !$this->to_boolean($data_options['cns']['donotcopy']);
-      $paramsStLight["hashAddressBar"] = $this->to_boolean($data_options['cns']['hashaddress']);
-      if (!($paramsStLight["hashAddressBar"]) && $paramsStLight["doNotCopy"]) {
-        $paramsStLight["doNotHash"] = TRUE;
+      $params_stlight["doNotCopy"] = !$this->toBoolean($data_options['cns']['donotcopy']);
+      $params_stlight["hashAddressBar"] = $this->toBoolean($data_options['cns']['hashaddress']);
+      if (!($params_stlight["hashAddressBar"]) && $params_stlight["doNotCopy"]) {
+        $params_stlight["doNotHash"] = TRUE;
       }
       else {
-        $paramsStLight["doNotHash"] = FALSE;
+        $params_stlight["doNotHash"] = FALSE;
       }
     }
     if (isset($data_options['onhover']) && $data_options['onhover'] == FALSE) {
-      $paramsStLight['onhover'] = FALSE;
+      $params_stlight['onhover'] = FALSE;
     }
     if ($data_options['neworzero']) {
-      $paramsStLight['newOrZero'] = "zero";
+      $params_stlight['newOrZero'] = "zero";
     }
     if (!$data_options['shorten']) {
-      $paramsStLight['shorten'] = 'false';
+      $params_stlight['shorten'] = 'false';
     }
-    $stlight = Json::encode($paramsStLight);
-    return $paramsStLight;
+
+    return $params_stlight;
   }
 
   /**
    * {@inheritdoc}
    */
-  function to_boolean($val) {
+  public function toBoolean($val) {
     if (strtolower(trim($val)) === 'false') {
       return FALSE;
     }
@@ -186,9 +184,9 @@ class SharethisManager implements SharethisManagerInterface {
   }
 
   /**
-   *
+   * {@inheritdoc}
    */
-  function renderSpans($data_options, $mtitle, $mpath) {
+  public function renderSpans($data_options, $mtitle, $mpath) {
     foreach ($data_options['option_extras'] as $service) {
       $data_options['services'] .= ',"' . $service . '"';
     }
@@ -209,18 +207,18 @@ class SharethisManager implements SharethisManagerInterface {
       }
 
       // Find the service code name.
-      $serviceCodeName = Unicode::substr($service[1], 0, -1);
+      $service_code_name = Unicode::substr($service[1], 0, -1);
 
       // Switch the title on a per-service basis if required.
       // $mtitle = $mtitle;.
-      switch ($serviceCodeName) {
+      switch ($service_code_name) {
         case 'twitter':
           $mtitle = empty($data_options['twitter_suffix']) ? $mtitle : Html::escape($mtitle) . ' ' . Html::escape($data_options['twitter_suffix']);
           break;
       }
 
       // Sanitize the service code for display.
-      $display = Html::escape($serviceCodeName);
+      $display = Html::escape($service_code_name);
 
       // Put together the span attributes.
       $attributes = array(
@@ -228,7 +226,7 @@ class SharethisManager implements SharethisManagerInterface {
         'st_title' => $mtitle,
         'class' => 'st_' . $display . $type,
       );
-      if ($serviceCodeName == 'twitter') {
+      if ($service_code_name == 'twitter') {
         if (!empty($data_options['twitter_handle'])) {
           $attributes['st_via'] = $data_options['twitter_handle'];
           $attributes['st_username'] = $data_options['twitter_recommends'];
@@ -248,7 +246,13 @@ class SharethisManager implements SharethisManagerInterface {
       // Render the span tag.
       $st_spans .= drupal_render($meta_generator);
     }
-    return ['data_options' => $data_options, 'm_path' => $mpath, 'm_title' => $mtitle , 'st_spans' => $st_spans];
+
+    return [
+      'data_options' => $data_options,
+      'm_path' => $mpath,
+      'm_title' => $mtitle ,
+      'st_spans' => $st_spans,
+    ];
   }
 
 }
diff --git a/src/Tests/SharethisBlockTest.php b/src/Tests/SharethisBlockTest.php
index fb8252e..81d8677 100644
--- a/src/Tests/SharethisBlockTest.php
+++ b/src/Tests/SharethisBlockTest.php
@@ -21,14 +21,20 @@ class SharethisBlockTest extends NodeTestBase {
    *
    * @var array
    */
-  public static $modules = array('node', 'system_test', 'block' , 'user', 'sharethis' , 'menu_ui');
+  public static $modules = array(
+    'node', 'system_test', 'block', 'user', 'sharethis', 'menu_ui',
+  );
+
   /**
    * {@inheritdoc}
    */
   protected function setUp() {
     parent::setUp();
     // Create and login user.
-    $admin_user = $this->drupalCreateUser(array('administer blocks', 'administer site configuration', 'access administration pages', 'administer sharethis', 'administer nodes'));
+    $admin_user = $this->drupalCreateUser(array(
+      'administer blocks', 'administer site configuration',
+      'access administration pages', 'administer sharethis', 'administer nodes',
+    ));
     $this->drupalLogin($admin_user);
   }
 
diff --git a/src/Tests/SharethisConfigFormTest.php b/src/Tests/SharethisConfigFormTest.php
index 6aeeedd..cff1342 100644
--- a/src/Tests/SharethisConfigFormTest.php
+++ b/src/Tests/SharethisConfigFormTest.php
@@ -2,6 +2,7 @@
 
 /**
  * @file
+ * Definition of \Drupal\sharethis\Tests\SharethisConfigFormTest.
  */
 
 namespace Drupal\sharethis\Tests;
@@ -40,7 +41,7 @@ class SharethisConfigFormTest extends NodeTestBase {
   /**
    * Tests the SharethisConfigForm.
    */
-  function testSharethisConfigForm() {
+  public function testSharethisConfigForm() {
     // Test that out of range values are picked up.
     $edit['location'] = 'content';
     $edit['callesi'] = 1;
@@ -62,7 +63,7 @@ class SharethisConfigFormTest extends NodeTestBase {
   /**
    * Tests the SharethisConfigForm.
    */
-  function testSharethisConfigFormlinks() {
+  public function testSharethisConfigFormlinks() {
 
     // Testing sharelinks on links present in a node.
     $edit['location'] = 'links';
diff --git a/src/Tests/Views/SharethisViewsPluginTest.php b/src/Tests/Views/SharethisViewsPluginTest.php
index 35ebe71..f92958e 100644
--- a/src/Tests/Views/SharethisViewsPluginTest.php
+++ b/src/Tests/Views/SharethisViewsPluginTest.php
@@ -32,7 +32,9 @@ class SharethisViewsPluginTest extends ViewTestBase {
    *
    * @var array
    */
-  public static $modules = array('node', 'system_test', 'views', 'user', 'sharethis', 'sharethis_test_views');
+  public static $modules = array(
+    'node', 'system_test', 'views', 'user', 'sharethis', 'sharethis_test_views',
+  );
   public static $testViews = array('test_sharethis');
   /**
    * {@inheritdoc}

diff --git a/src/SharethisManagerInterface.php b/src/SharethisManagerInterface.php
index ff301d7..ac1046c 100644
--- a/src/SharethisManagerInterface.php
+++ b/src/SharethisManagerInterface.php
@@ -39,35 +39,40 @@ interface SharethisManagerInterface {
   /**
    * Include st js scripts.
    */
-  public function sharethis_include_js();
+  public function sharethisIncludeJs();
 
 
   /**
-   * Get_stLight_options() function is creating options to be passed to stLight.options
-   * $data_options array is the settings selected by publisher in admin panel.
+   * function is creating options to be passed to stLight.
+   *
+   * @param array $data_options
+   *   The settings selected by publisher in admin panel.
+   *
    */
-  public function get_stLight_options($data_options);
+  public function getShareThisLightOptions($data_options);
 
 
   /**
    * Converts given value to boolean.
    *
-   * @param val
+   * @param $val
    *   Which value to convert to boolean
    *
    * @return bool
    *
    * @todo To be replaced with bool
    */
-  function to_boolean($val);
+  public function toBoolean($val);
 
   /**
    * Custom html block.
    *
    * @param array, string, string
    *
    * @return array
    */
-  public function renderSpans($array, $string, $string);
+  public function renderSpans($array, $title, $string);
 
 }
@@ -39,35 +39,40 @@ interface SharethisManagerInterface {
    * Custom html block.
    *
-   * @param array, string, string
+   * @param array $array
+   * @param string $title
+   * @param string $string
    *
    * @return array